//Copyright (C) Microsoft Corporation.  All rights reserved.

namespace nwind {
    using System;
    using System.Collections.Generic;
    using System.Reflection;
    using System.Linq;
    using System.Linq.Expressions;
    using System.Data;
    using System.Data.Linq;
    using System.Data.Linq.Mapping;

    public partial class NorthwindInheritance : DataContext {
        public Table<BaseContact> Contacts;

        public NorthwindInheritance(string connection)
            : base(connection) {
        }

        public NorthwindInheritance(System.Data.IDbConnection connection)
            : base(connection) {
        }
    }

    /*
     *                  Contact
     *                 /      \
     *       ShipperContact   FullContact (abstract)
     *                       /     |     \
     *               Customer   Employee  Supplier
     *               Contact    Contact   Contact
     */
    [Table(Name = "Contacts")]
    [InheritanceMapping(Code = "Unknown", Type = typeof(BaseContact), IsDefault = true)]
    [InheritanceMapping(Code = "Customer", Type = typeof(CustomerContact))]
    [InheritanceMapping(Code = "Supplier", Type = typeof(SupplierContact))]
    [InheritanceMapping(Code = "Employee", Type = typeof(EmployeeContact))]
    [InheritanceMapping(Code = "Shipper", Type = typeof(ShipperContact))]
    public class BaseContact {
        [Column(DbType = "INT NOT NULL", IsPrimaryKey = true, IsDbGenerated = true)]
        public int ContactID;

        [Column(DbType = "NVARCHAR(50)", IsDiscriminator = true)]
        public string ContactType;

        [Column(DbType = "NVARCHAR(40)")]
        public string CompanyName;

        [Column(DbType = "NVARCHAR(24)")]
        public string Phone;
    }

    public class ShipperContact : BaseContact {
    }

    public abstract class FullContact : BaseContact {
        [Column(DbType = "NVARCHAR(40)")]
        public string ContactName;

        [Column(DbType = "NVARCHAR(30)")]
        public string ContactTitle;

        [Column(DbType = "NVARCHAR(60)")]
        public string Address;

        [Column(DbType = "NVARCHAR(15)")]
        public string City;

        [Column(DbType = "NVARCHAR(15)")]
        public string Region;

        [Column(DbType = "NVARCHAR(10)")]
        public string PostalCode;

        [Column(DbType = "NVARCHAR(15)")]
        public string Country;

        [Column(DbType = "NVARCHAR(24)")]
        public string Fax;
    }

    public class SupplierContact : FullContact {
        [Column(DbType = "NTEXT")]
        public string HomePage;
    }

    public class CustomerContact : FullContact {
    }

    public class EmployeeContact : FullContact {
        [Column(DbType = "NVARCHAR(4)")]
        public string Extension;

        [Column(DbType = "NVARCHAR(255)")]
        public string PhotoPath;

        [Column(DbType = "IMAGE")]
        public byte[] Photo;
    }
}
